/* ***************************************
    DRACHENTURMUHR by LED-Steampunk
******************************************
  Version 4-0 August 2021 mit neuer NTP aus der ESP8266 Bibliothek
  
  Binäruhr nach dem Vorbild der Rheinturmuhr zu Düsseldorf
  Aufbau mit Neopixeln, WiFi Konfiguration über Accespoint, Zeitabfrage alle 60 Sekunden über NTP

  
  Pixel Adressen (Standard Aufbau):
  Einerstelle, Trenner, Zehnerstelle, Trenner
  Sekunden  0-8,  9, 10-14, 15
  Minuten 16-24, 25, 26-30, 31
  Stunden 32-40, 41, 42-43, 44

  Pixel Adressen (LITTLE Aufbau):
  Einerstelle, Trenner, Zehnerstelle, Trenner
  Statusanzeige  0
  Minuten 1-9, 10, 11-15, 16
  Stunden 17-25, 26, 27-28
  
*/

int SW_VERSION =401;


//#define DEBUG //serielle Debug Ausgaben aktivieren
//#define LITLE //Litle Dragon Clock, einfache Anzeige ohne Sekundenanzeige mit Sekundenblinker auf erstem BIT
#define FIRE // Feuer Effekt zur Anzeige der Zeit.
#define LIGHTSHOW // Lightshow beim Start und zu zufälliger Minute

#define MYTZ TZ_Europe_Berlin // Zeitzone festlegen

// Farbdefinitionen für Trennstellen ( trenn_ ) und Zählstellen ( cnt_ ) 0-255 
// bei Feuerflackern zusätzlich minimaler und maximaler Rot Wert ( cnt_rf_) 
// !!! Bei Werten über 100, ausreichende Stromversorgung und Kabel beachten !!!

int trenn_r = 40 ;
int trenn_g = 0 ;
int trenn_b = 0 ;

int cnt_r = 60 ;
int cnt_g = 30 ;
int cnt_b =  0;

#ifdef FIRE
int cnt_rf_min = 30;
int cnt_rf_max = 60;
#endif


/* -----------------------------------------------
***************************************************
           ENDE der DEFINITIONEN
    ab hier keine Änderungen mehr vornehmen
***************************************************
--------------------------------------------------*/

#include <WiFiManager.h> //WIFI Manager Konfiguration per Accespoint
#include <TZ.h> // automatische Zeitzonen Anpassung auf DST
#include <turmuhr.h> // Programmroutinen für die Ausgabe zur Turmuhr
#include <ESP8266WiFi.h>
#include <coredecls.h>                  // settimeofday_cb()
#include <PolledTimeout.h>
#include <time.h>                       // time() ctime()

extern "C" int clock_gettime(clockid_t unused, struct timespec *tp); // this line is necessary for first TimeGet
static time_t now; // An object which can store a time

int delayval = 500; // delay for half a second

void setup() {
  Serial.begin(115200);
  Serial.println("\nStarting...\n");
  Serial.println("DRAGONCLOCK, by LED-Steampunk");
  Serial.print("Software Version  ");
  Serial.println(SW_VERSION);
  pixels.begin();
  pixels.setBrightness(20);
  delay(delayval); // Delay for a period of time (in milliseconds).

 // alle Pixel löschen 
  for (int i = 0; i < NUMPIXELS; i++)  
    {
    // pixels.Color takes RGB values, from 0,0,0 up to 255,255,255
    pixels.setPixelColor(i, pixels.Color(0, 0, 0));
    pixels.show(); // This sends the updated pixel color to the hardware.
  }
#ifdef LIGHTSHOW
    lightshow_1(5); // Lightshow 1 starten
    lightshow_2(5); // Lightshow 1 starten
    lightshow_1(5); // Lightshow 1 starten
#endif

  // start network with WiFi-Manager
  WiFiManager wifiManager; // wifi configuration wizard
  wifiManager.autoConnect("Dragon_Clock", "12345678"); // configuration for the access point, set your own secret.

  // install callback - called when settimeofday is called (by SNTP or us)
  // once enabled (by DHCP), SNTP is updated every hour
  // settimeofday_cb(time_is_set_scheduled);

  // This is where your time zone is set
  configTime(MYTZ, "pool.ntp.org");
 
}

void loop() {
 //get actual time from NTP and show on serial debug
 /*
  if (showTimeNow) {
    showTime();
  }
 */

  now = time(nullptr);      // Updates the 'now' variable to the current time value
  //convert to simple values for shift-out
  stunden = (localtime(&now)->tm_hour);
  minuten = (localtime(&now)->tm_min);
  sekunden = (localtime(&now)->tm_sec);
  show_out();


  // human readable debug
#ifdef DEBUG 
  Serial.print("ctime:     ");
  Serial.print(ctime(&now));
  Serial.print(stunden);
  Serial.print(":");
  Serial.print(minuten);
  Serial.print(":");
  Serial.print(sekunden);
  Serial.println("");

#endif

delay(50);



}